@@ -22,8 +22,8 @@
 ################################################################################
 
 
-.aggregate.timeSeries <- 
-    function(x, by, FUN, ...)
+## GNB: 2024-01-11 GNB: streamlined and removed the S4 method
+aggregate.timeSeries <- function(x, by, FUN, ...)
 {
     # A function implemented by Yohan Chalabi and Diethelm Wuertz
 
@@ -70,11 +70,11 @@
     Title <- x@title
     Documentation <- x@documentation
 
-    # Make sure that x is sorted:
+    # Make sure that x is sorted (by timedate):
     if (is.unsorted(x))
         x <- sort(x)
 
-    # Sort and remove double entries in by:
+    # Sort and remove duplicated entries in by:
     by <- unique(sort(by))
 
     INDEX <- findInterval(x@positions, as.numeric(by, "sec") + 1)
@@ -97,12 +97,12 @@
 }
 
 
-setMethod("aggregate", "timeSeries", function(x, by, FUN, ...)
-          .aggregate.timeSeries(x, by, FUN, ...))
-
-          
-# until UseMethod dispatches S4 methods in 'base' functions
-aggregate.timeSeries <- function(x, ...) .aggregate.timeSeries(x, ...)
+## GNB: 2024-01-11 GNB: streamlined and removed the S4 method
+## setMethod("aggregate", "timeSeries", function(x, by, FUN, ...)
+##           .aggregate.timeSeries(x, by, FUN, ...))
+##         
+## # until UseMethod dispatches S4 methods in 'base' functions
+## aggregate.timeSeries <- function(x, ...) .aggregate.timeSeries(x, ...)
 
 
 ################################################################################
@@ -185,5 +185,3 @@ daily2weekly <-
 
 
 ###############################################################################
-
-
